@@ -24,7 +24,7 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =cut
 
-our $VERSION = '3.7.2';
+our $VERSION = '3.7.4';
 
 =head1 SYNOPSIS
 
@@ -72,10 +72,9 @@ my %valid_options = (
     comments_order      => {valid => [qw(time relevance)],                default => 'time'},
     subscriptions_order => {valid => [qw(alphabetical relevance unread)], default => undef},
 
-    # Others
+    # Misc
     debug       => {valid => [0 .. 3],     default => 0},
     lwp_timeout => {valid => [qr/^\d+\z/], default => 1},
-    key         => {valid => [qr/^.{5}/],  default => undef},
     config_dir  => {valid => [qr/^./],     default => q{.}},
     cache_dir   => {valid => [qr/^./],     default => q{.}},
 
@@ -83,15 +82,17 @@ my %valid_options = (
     lwp_env_proxy => {valid => [1, 0], default => 1},
     escape_utf8   => {valid => [1, 0], default => 0},
     prefer_mp4    => {valid => [1, 0], default => 0},
+    prefer_av1    => {valid => [1, 0], default => 0},
 
     use_invidious_api => {valid => [1, 0], default => 0},
 
-    # OAuth stuff
-    client_id     => {valid => [qr/^.{5}/], default => undef},
-    client_secret => {valid => [qr/^.{5}/], default => undef},
-    redirect_uri  => {valid => [qr/^.{5}/], default => undef},
-    access_token  => {valid => [qr/^.{5}/], default => undef},
-    refresh_token => {valid => [qr/^.{5}/], default => undef},
+    # API/OAuth
+    key           => {valid => [qr/^.{15}/], default => undef},
+    client_id     => {valid => [qr/^.{15}/], default => undef},
+    client_secret => {valid => [qr/^.{15}/], default => undef},
+    redirect_uri  => {valid => [qr/^.{15}/], default => undef},
+    access_token  => {valid => [qr/^.{15}/], default => undef},
+    refresh_token => {valid => [qr/^.{15}/], default => undef},
 
     authentication_file => {valid => [qr/^./], default => undef},
 
@@ -176,8 +177,6 @@ sub new {
         }
     }
 
-    $self->load_authentication_tokens();
-
     foreach my $invalid_key (keys %opts) {
         warn "Invalid key: '${invalid_key}'";
     }
@@ -542,7 +541,7 @@ sub _extract_from_ytdl {
                 my $entry = {
                              itag => $format->{format_id},
                              url  => $format->{url},
-                             type => ((($format->{format_note} // '') eq 'DASH audio') ? 'audio/' : 'video/') . $format->{ext},
+                             type => ((($format->{format} // '') =~ /audio only/i) ? 'audio/' : 'video/') . $format->{ext},
                             };
 
                 push @formats, $entry;
@@ -847,15 +846,29 @@ sub get_streaming_urls {
         @streaming_urls = $self->_fallback_extract_urls($videoID);
     }
 
-    if ($self->get_prefer_mp4) {
+    if ($self->get_prefer_mp4 or $self->get_prefer_av1) {
 
-        my @mp4_urls;
+        my @video_urls;
         my @audio_urls;
 
+        require WWW::YoutubeViewer::Itags;
+
+        my %audio_itags;
+        @audio_itags{@{WWW::YoutubeViewer::Itags->get_itags->{audio}}} = ();
+
         foreach my $url (@streaming_urls) {
-            if ($url->{type} =~ /\bvideo\b/) {
-                if ($url->{type} =~ /\bmp4\b/) {
-                    push @mp4_urls, $url;
+
+            if (exists($audio_itags{$url->{itag}})) {
+                push @audio_urls, $url;
+                next;
+            }
+
+            if ($url->{type} =~ /\bvideo\b/i) {
+                if ($self->get_prefer_mp4 and $url->{type} =~ /\bmp4\b/i) {
+                    push @video_urls, $url;
+                }
+                elsif ($self->get_prefer_av1 and $url->{type} =~ /\bav[0-9]+\b/i) {
+                    push @video_urls, $url;
                 }
             }
             else {
@@ -863,8 +876,8 @@ sub get_streaming_urls {
             }
         }
 
-        if (@mp4_urls) {
-            @streaming_urls = (@mp4_urls, @audio_urls);
+        if (@video_urls) {
+            @streaming_urls = (@video_urls, @audio_urls);
         }
     }
 
